==> sarg_2.0.2.orig.tar.gz: sarg_2.0.2.orig/sarg-php/sarg-block-it.php <==
<?php

/*
 * AUTHOR: Pedro Lineu Orso                             orso@brturbo.com
 *                                                           1998 - 2004
 * SARG Squid Analisys Report Generator            http://sarg-squid.org
 * ---------------------------------------------------------------------
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
 *
 */

$filename = "/usr/local/squid/etc/block.txt";

$url = $_GET['url'];
$url = $url."\n";

$ha = fopen($filename, 'a');
if ($filename == false) {
   print (gettext ("Could not open the filename"));
   echo '&nbsp;'.$filename;
   exit;
}
else {
   $written = fwrite($ha, $url);
   fclose($ha);
   if ($written != strlen($url)) {
      print (gettext ("Write error"));
      exit;
   }
   print (gettext ("Done!"));
   echo "<br><br>\n";
   echo "<a href=\"javascript:history.go(-1)\">";
   print (gettext("Return"));
   echo "</a>&nbsp;";
   print (gettext (" to Sarg."));
}

==> sarg_2.4.0.orig.tar.gz: sarg-2.4.0/sarg-php/sarg-block-it.php <==
<?php

/*
 * AUTHOR: Pedro Lineu Orso                         pedro.orso@gmail.com
 *                                                            1998, 2006
 * SARG Squid Analysis Report Generator            http://sarg-squid.org
 *
 * SARG donations:
 *      please look at http://sarg.sourceforge.net/donations.php
 * ---------------------------------------------------------------------
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111, USA.
 *
 */

require_once "config.php.inc";

if (!isset($_GET['url']))
{
	echo "<p>",gettext("No URL passed as argument"),"</p>\n";
	exit;
}
$url = $_GET['url'];
$url = $url."\n";

$ha = fopen($DefaultSquidBlock, 'a');
if ($ha == false) {
   printf(gettext("Could not open file: %s"),$DefaultSquidBlock);
   exit;
}
else {
   $written = fwrite($ha, $url);
   fclose($ha);
   if ($written != strlen($url)) {
      print (gettext ("Write error"));
      exit;
   }
   print (gettext ("Done!"));
   echo "<br><br>\n";
   printf(gettext("<a href=\"%s\">Return</a> to Sarg."),"javascript:history.go(-1)");
}
